package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.SignedData;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.x509.X509StreamParserSpi;
import cn.com.infosec.x509.util.StreamParsingException;
import java.io.BufferedInputStream;
import java.io.InputStream;
import java.security.cert.Certificate;
import java.util.ArrayList;
import java.util.Collection;

public class X509CertParser extends X509StreamParserSpi {
   private static final PEMUtil PEM_PARSER = new PEMUtil("CERTIFICATE");
   private ASN1Set sData = null;
   private int sDataObjectCount = 0;
   private InputStream currentStream = null;

   private Certificate readDERCertificate(InputStream in) {
      ASN1Sequence in1;
      if ((in1 = (ASN1Sequence)(new ASN1InputStream(in, ProviderUtil.getReadLimit(in))).readObject()).size() > 1 && in1.getObjectAt(0) instanceof DERObjectIdentifier && in1.getObjectAt(0).equals(PKCSObjectIdentifiers.signedData)) {
         this.sData = (new SignedData(ASN1Sequence.getInstance((ASN1TaggedObject)in1.getObjectAt(1), true))).getCertificates();
         return this.getCertificate();
      } else {
         return new X509CertificateObject(X509CertificateStructure.getInstance(in1));
      }
   }

   private Certificate getCertificate() {
      if (this.sData != null) {
         while(this.sDataObjectCount < this.sData.size()) {
            ASN1Set var10000 = this.sData;
            int var1;
            this.sDataObjectCount = (var1 = this.sDataObjectCount) + 1;
            DEREncodable var2;
            if ((var2 = var10000.getObjectAt(var1)) instanceof ASN1Sequence) {
               return new X509CertificateObject(X509CertificateStructure.getInstance(var2));
            }
         }
      }

      return null;
   }

   private Certificate readPEMCertificate(InputStream in) {
      ASN1Sequence var2;
      return (var2 = PEM_PARSER.readPEMObject(in)) != null ? new X509CertificateObject(X509CertificateStructure.getInstance(var2)) : null;
   }

   public void engineInit(InputStream in) {
      this.currentStream = in;
      this.sData = null;
      this.sDataObjectCount = 0;
      if (!in.markSupported()) {
         this.currentStream = new BufferedInputStream(this.currentStream);
      }

   }

   public Object engineRead() {
      Exception var10000;
      label57: {
         ASN1Set var11;
         boolean var10001;
         try {
            var11 = this.sData;
         } catch (Exception var8) {
            var10000 = var8;
            var10001 = false;
            break label57;
         }

         ASN1Set var1 = var11;
         int var12;
         if (var11 != null) {
            label44: {
               int var13;
               try {
                  var12 = this.sDataObjectCount;
                  var13 = var1.size();
               } catch (Exception var4) {
                  var10000 = var4;
                  var10001 = false;
                  break label44;
               }

               if (var12 != var13) {
                  try {
                     return this.getCertificate();
                  } catch (Exception var2) {
                     var10000 = var2;
                     var10001 = false;
                  }
               } else {
                  try {
                     this.sData = null;
                     this.sDataObjectCount = 0;
                     return null;
                  } catch (Exception var3) {
                     var10000 = var3;
                     var10001 = false;
                  }
               }
            }
         } else {
            label59: {
               try {
                  this.currentStream.mark(10);
                  var12 = this.currentStream.read();
               } catch (Exception var7) {
                  var10000 = var7;
                  var10001 = false;
                  break label59;
               }

               int var10 = var12;
               if (var12 == -1) {
                  return null;
               }

               if (var10 != 48) {
                  try {
                     this.currentStream.reset();
                     return this.readPEMCertificate(this.currentStream);
                  } catch (Exception var5) {
                     var10000 = var5;
                     var10001 = false;
                  }
               } else {
                  try {
                     this.currentStream.reset();
                     return this.readDERCertificate(this.currentStream);
                  } catch (Exception var6) {
                     var10000 = var6;
                     var10001 = false;
                  }
               }
            }
         }
      }

      Exception var9 = var10000;
      throw new StreamParsingException(var9.toString(), var9);
   }

   public Collection engineReadAll() {
      ArrayList var1;
      var1 = new ArrayList.<init>();

      Certificate var2;
      while((var2 = (Certificate)this.engineRead()) != null) {
         var1.add(var2);
      }

      return var1;
   }
}
